import React from 'react';
import PropTypes from 'prop-types';
import classnames from 'classnames/bind';
import styles from './AnueSearchRealtimeResult.scss';
import AnueLink from '../../utils/anueLink';

const cx = classnames.bind(styles);

export default function SearchResultContentWrapper({
  title,
  headerActionName,
  onHeaderActionClick,
  isLoaded,
  children,
  more,
  keyword,
  env,
}) {
  const anueUtilLink = new AnueLink(env);
  const link = anueUtilLink.generateSearchMoreLink({ title, keyword });

  return (
    <div className={cx('search-result-content-wrapper', { display: isLoaded })}>
      {title && (
        <div className={cx('search-result-content-wrapper__header')}>
          {<p>{title}</p>}
          {more && <a href={link}>{more}</a>}
          {headerActionName && <span onClick={onHeaderActionClick}>{headerActionName}</span>}
        </div>
      )}
      {children}
    </div>
  );
}

SearchResultContentWrapper.propTypes = {
  title: PropTypes.string,
  headerActionName: PropTypes.string,
  onHeaderActionClick: PropTypes.func,
  isLoaded: PropTypes.bool,
  children: PropTypes.arrayOf(PropTypes.element),
  more: PropTypes.string,
  keyword: PropTypes.string,
  env: PropTypes.string.isRequired,
};

SearchResultContentWrapper.defaultProps = {
  title: null,
  headerActionName: null,
  onHeaderActionClick: () => {},
  onRowActionClick: () => {},
  isLoaded: false,
  isCols: false,
  children: null,
  more: null,
  keyword: null,
};
