import { driverNameEllipsisHelper, newsPublishedDateHelper } from '../helpers';

describe('driverNameEllipsisHelper', () => {
  it('should return original input string', () => {
    expect(driverNameEllipsisHelper('原力覺醒老司機')).toBe('原力覺醒老司機');
  });
  it('should return the clopped string and following with ellipsis', () => {
    // Each word of 一二三四五六七八九十一二 is equivalent to length 24 so we cut the second 二 and add `...` to make the length less than 24.
    expect(driverNameEllipsisHelper('一二三四五六七八九十一二三四五六七八九十')).toBe('一二三四五六七八九十一...');
    // mark tag cases
    expect(driverNameEllipsisHelper('<mark>一二三四五</mark>六七八九十一二三四五六七八九十')).toBe(
      '<mark>一二三四五</mark>六七八九十一...'
    );
    expect(driverNameEllipsisHelper('<mark>一二三四五六七八九十一二三四五六七八九十</mark>')).toBe(
      '<mark>一二三四五六七八九十一</mark>...'
    );
    expect(driverNameEllipsisHelper('一二三四五六<mark>七八九十一二三四五六七八九十</mark>')).toBe(
      '一二三四五六<mark>七八九十一</mark>...'
    );
    // Each word of 123456789012345678901234 is equivalent to length 24 so we cut the second 4 and add `...` to make the length less than 24.
    expect(driverNameEllipsisHelper('1234567890123456789012345')).toBe('12345678901234567890123...');
    // Each word of abcdefghijklmnopqrstuvwy is equivalent to length 24 so we cut the second y and add `...` to make the length less than 24.
    expect(driverNameEllipsisHelper('abcdefghijklmnopqrstuvwxyz')).toBe('abcdefghijklmnopqrstuvw...');
    // Each word of ABCDEFGHIJKLMNO is equivalent to length 24 so we cut the second O and add `...` to make the length less than 24.
    expect(driverNameEllipsisHelper('ABCDEFGHIJKLMNOPQRSTUVWXYZ')).toBe('ABCDEFGHIJKLMNO...');
  });
});

const MOCK_TS = 1586707200000; // 2020/4/13

describe('newsPublishedDateHelper', () => {
  const date = Date.now;

  beforeEach(() => {
    global.Date.now = jest.fn(() => new Date(MOCK_TS));
  });
  afterAll(() => {
    global.Date.now = date;
  });

  it('should render the hours', () => {
    const phpTs = Math.floor((MOCK_TS - 60 * 60 * 8 * 1000) / 1000);

    expect(newsPublishedDateHelper(phpTs)).toBe('8 小時前');
  });
  it('should render the date', () => {
    const phpTs = Math.floor((MOCK_TS - 60 * 60 * 24 * 1000) / 1000);

    expect(newsPublishedDateHelper(phpTs)).toBe('2020/4/12');
  });
});
