const ZERO_CHART_CODE_AT = '0'.charCodeAt();
const NINE_CHART_CODE_AT = '9'.charCodeAt();
const FIRST_ALPHABET_CHART_CODE_AT = 'a'.charCodeAt();
const LAST_ALPHABET_CHART_CODE_AT = 'z'.charCodeAt();
const FIRST_CAPITAL_ALPHABET_CHART_CODE_AT = 'A'.charCodeAt();
const LAST_CAPITAL_ALPHABET_CHART_CODE_AT = 'Z'.charCodeAt();

const MAX_TEXT_LENGTH = 24;

export const findMarkTagIdx = string => {
  const startRegex = string.match('<mark>');
  const endRegex = string.replace('<mark>', '').match('</mark>');
  const markStartIdx = startRegex && startRegex.index;
  const markEndIdx = endRegex && endRegex.index;

  return {
    markStartIdx,
    markEndIdx,
  };
};

export const driverNameEllipsisHelper = htmlString => {
  if (!htmlString) {
    return null;
  }

  let lengthCount = 0;
  const map = ['<mark>', '</mark>'];

  const stringArry = htmlString.split(/<\/?mark>/);
  const next = [];

  for (let i = 0; i < stringArry.length; i++) {
    const currentChunk = stringArry[i];

    for (let j = 0; j < currentChunk.length; j++) {
      const c = currentChunk[j].charCodeAt();

      if (
        (ZERO_CHART_CODE_AT <= c && NINE_CHART_CODE_AT >= c) ||
        (FIRST_ALPHABET_CHART_CODE_AT <= c && LAST_ALPHABET_CHART_CODE_AT >= c)
      ) {
        // eslint-disable-next-line no-param-reassign
        lengthCount += 1;
      } else if (FIRST_CAPITAL_ALPHABET_CHART_CODE_AT <= c && LAST_CAPITAL_ALPHABET_CHART_CODE_AT >= c) {
        // eslint-disable-next-line no-param-reassign
        lengthCount += 1.5;
      } else {
        // eslint-disable-next-line no-param-reassign
        lengthCount += 2;
      }

      if (lengthCount >= MAX_TEXT_LENGTH) {
        break;
      }

      next.push(currentChunk[j]);
    }

    if (i !== stringArry.length - 1) {
      next.push(map[i % 2]);
    }

    if (lengthCount >= MAX_TEXT_LENGTH) {
      break;
    }
  }

  return lengthCount >= MAX_TEXT_LENGTH ? `${next.join('')}...` : next.join('');
};

export const newsPublishedDateHelper = phpTs => {
  const ts = phpTs * 1000;
  const hoursBackTimestamp = Date.now() - ts;

  if (hoursBackTimestamp < 24 * 60 * 60 * 1000) {
    return `${Math.floor(hoursBackTimestamp / (60 * 60 * 1000))} 小時前`;
  }

  const d = new Date(ts);

  return `${d.getFullYear()}/${d.getMonth() + 1}/${d.getDate()}`;
};
