import React, { Component } from 'react';
import PropTypes from 'prop-types';
import classnames from 'classnames/bind';
import styles from './LazyImage.scss';

const cx = classnames.bind(styles);

export default class LazyImage extends Component {
  static propTypes = {
    src: PropTypes.string,
    isRounded: PropTypes.bool,
  };
  static defaultProps = {
    src: null,
    isRounded: false,
  };

  constructor() {
    super();

    this.source = new Image();
    this.state = {
      isLoaded: false,
    };
  }

  componentDidMount() {
    const { src } = this.props;

    this.source.addEventListener('load', this.handleOnLoaded);
    this.source.src = src;
  }

  handleOnLoaded = () => {
    this.setState({
      isLoaded: true,
    });
  };

  render() {
    const { src, isRounded } = this.props;
    const { isLoaded } = this.state;

    return (
      <div className={cx('lazy-img', { loaded: isLoaded, rounded: isRounded })}>
        <img src={src} alt="Anue 鉅亨" />
      </div>
    );
  }
}
