import React from 'react';
import { storiesOf } from '@storybook/react';
import { withInfo } from '@storybook/addon-info';
import { withNotes } from '@storybook/addon-notes';
import * as knobs from '@storybook/addon-knobs/react';
import SwitchVersionButton, { OLD_VERSION } from '../SwitchVersionButton';
import defaultNotes from './SwitchVersionButton.md';
import styles from './stories.style.scss';

const stories = storiesOf('SwitchVersionButton', module);

stories.addDecorator(knobs.withKnobs);
stories.addDecorator(story => <div style={{ width: '334px' }}>{story()}</div>);

stories.add(
  '預設',
  withNotes(defaultNotes)(
    withInfo()(() => {
      return (
        <SwitchVersionButton
          onSwitchVersion={() => {
            alert('版本切換中');
          }}
        />
      );
    })
  )
);

stories.add(
  '變更文字樣式',
  withNotes(defaultNotes)(
    withInfo()(() => {
      return (
        <SwitchVersionButton
          iconClassName={styles.icon}
          textClassName={styles.button}
          onSwitchVersion={() => {
            alert('版本切換中');
          }}
        />
      );
    })
  )
);

stories.add(
  '設定目前顯示版本為舊版',
  withNotes(defaultNotes)(
    withInfo()(() => {
      return (
        <SwitchVersionButton
          defaultVersion={OLD_VERSION}
          divider="right"
          onSwitchVersion={() => {
            alert('版本切換中');
          }}
        />
      );
    })
  )
);
